# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/video/v1/playlist_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/video/v1/playlist_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.video.v1 import playlist_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_playlist__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/video/v1/playlist_service.proto\x12\x15yandex.cloud.video.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a$yandex/cloud/video/v1/playlist.proto\"7\n\x12GetPlaylistRequest\x12!\n\x0bplaylist_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xab\x01\n\x14ListPlaylistsRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x1f\n\npage_token\x18\x65 \x01(\tB\x0b\x8a\xc8\x31\x07<=15000\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x1a\n\x06\x66ilter\x18g \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x02\x10\x64\"j\n\x15ListPlaylistsResponse\x12\x32\n\tplaylists\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.video.v1.Playlist\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\xac\x01\n\x15\x43reatePlaylistRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x05title\x18\x02 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=2500\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12=\n\x05items\x18\x04 \x03(\x0b\x32#.yandex.cloud.video.v1.PlaylistItemB\t\x82\xc8\x31\x05<=100\"-\n\x16\x43reatePlaylistMetadata\x12\x13\n\x0bplaylist_id\x18\x01 \x01(\t\"\xdf\x01\n\x15UpdatePlaylistRequest\x12!\n\x0bplaylist_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x34\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x19\n\x05title\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2500\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12=\n\x05items\x18\x05 \x03(\x0b\x32#.yandex.cloud.video.v1.PlaylistItemB\t\x82\xc8\x31\x05<=100\"-\n\x16UpdatePlaylistMetadata\x12\x13\n\x0bplaylist_id\x18\x01 \x01(\t\":\n\x15\x44\x65letePlaylistRequest\x12!\n\x0bplaylist_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65letePlaylistMetadata\x12\x13\n\x0bplaylist_id\x18\x01 \x01(\t\"h\n\x1b\x42\x61tchDeletePlaylistsRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\'\n\x0cplaylist_ids\x18\x02 \x03(\tB\x11\x82\xc8\x31\x05\x31-100\x8a\xc8\x31\x04<=50\"4\n\x1c\x42\x61tchDeletePlaylistsMetadata\x12\x14\n\x0cplaylist_ids\x18\x01 \x03(\t\"}\n\x1bGetPlaylistPlayerURLRequest\x12!\n\x0bplaylist_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12;\n\x06params\x18\x02 \x01(\x0b\x32+.yandex.cloud.video.v1.PlaylistPlayerParams\"F\n\x14PlaylistPlayerParams\x12\x0c\n\x04mute\x18\x01 \x01(\x08\x12\x10\n\x08\x61utoplay\x18\x02 \x01(\x08\x12\x0e\n\x06hidden\x18\x03 \x01(\x08\"@\n\x1cGetPlaylistPlayerURLResponse\x12\x12\n\nplayer_url\x18\x01 \x01(\t\x12\x0c\n\x04html\x18\x02 \x01(\t2\x99\t\n\x0fPlaylistService\x12|\n\x03Get\x12).yandex.cloud.video.v1.GetPlaylistRequest\x1a\x1f.yandex.cloud.video.v1.Playlist\")\x82\xd3\xe4\x93\x02#\x12!/video/v1/playlists/{playlist_id}\x12~\n\x04List\x12+.yandex.cloud.video.v1.ListPlaylistsRequest\x1a,.yandex.cloud.video.v1.ListPlaylistsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/video/v1/playlists\x12\x9f\x01\n\x06\x43reate\x12,.yandex.cloud.video.v1.CreatePlaylistRequest\x1a!.yandex.cloud.operation.Operation\"D\xb2\xd2*\"\n\x16\x43reatePlaylistMetadata\x12\x08Playlist\x82\xd3\xe4\x93\x02\x18\"\x13/video/v1/playlists:\x01*\x12\xad\x01\n\x06Update\x12,.yandex.cloud.video.v1.UpdatePlaylistRequest\x1a!.yandex.cloud.operation.Operation\"R\xb2\xd2*\"\n\x16UpdatePlaylistMetadata\x12\x08Playlist\x82\xd3\xe4\x93\x02&2!/video/v1/playlists/{playlist_id}:\x01*\x12\xb7\x01\n\x06\x44\x65lete\x12,.yandex.cloud.video.v1.DeletePlaylistRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*/\n\x16\x44\x65letePlaylistMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02#*!/video/v1/playlists/{playlist_id}\x12\xc9\x01\n\x0b\x42\x61tchDelete\x12\x32.yandex.cloud.video.v1.BatchDeletePlaylistsRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*5\n\x1c\x42\x61tchDeletePlaylistsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02$\"\x1f/video/v1/playlists:batchDelete:\x01*\x12\xaf\x01\n\x0cGetPlayerURL\x12\x32.yandex.cloud.video.v1.GetPlaylistPlayerURLRequest\x1a\x33.yandex.cloud.video.v1.GetPlaylistPlayerURLResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./video/v1/playlists/{playlist_id}:getPlayerURLB\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.playlist_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_GETPLAYLISTREQUEST'].fields_by_name['playlist_id']._loaded_options = None
  _globals['_GETPLAYLISTREQUEST'].fields_by_name['playlist_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTPLAYLISTSREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_LISTPLAYLISTSREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTPLAYLISTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPLAYLISTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_LISTPLAYLISTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTPLAYLISTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\007<=15000'
  _globals['_LISTPLAYLISTSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTPLAYLISTSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATEPLAYLISTREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_CREATEPLAYLISTREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEPLAYLISTREQUEST'].fields_by_name['title']._loaded_options = None
  _globals['_CREATEPLAYLISTREQUEST'].fields_by_name['title']._serialized_options = b'\350\3071\001\212\3101\006<=2500'
  _globals['_CREATEPLAYLISTREQUEST'].fields_by_name['items']._loaded_options = None
  _globals['_CREATEPLAYLISTREQUEST'].fields_by_name['items']._serialized_options = b'\202\3101\005<=100'
  _globals['_UPDATEPLAYLISTREQUEST'].fields_by_name['playlist_id']._loaded_options = None
  _globals['_UPDATEPLAYLISTREQUEST'].fields_by_name['playlist_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEPLAYLISTREQUEST'].fields_by_name['field_mask']._loaded_options = None
  _globals['_UPDATEPLAYLISTREQUEST'].fields_by_name['field_mask']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEPLAYLISTREQUEST'].fields_by_name['title']._loaded_options = None
  _globals['_UPDATEPLAYLISTREQUEST'].fields_by_name['title']._serialized_options = b'\212\3101\006<=2500'
  _globals['_UPDATEPLAYLISTREQUEST'].fields_by_name['items']._loaded_options = None
  _globals['_UPDATEPLAYLISTREQUEST'].fields_by_name['items']._serialized_options = b'\202\3101\005<=100'
  _globals['_DELETEPLAYLISTREQUEST'].fields_by_name['playlist_id']._loaded_options = None
  _globals['_DELETEPLAYLISTREQUEST'].fields_by_name['playlist_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BATCHDELETEPLAYLISTSREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_BATCHDELETEPLAYLISTSREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BATCHDELETEPLAYLISTSREQUEST'].fields_by_name['playlist_ids']._loaded_options = None
  _globals['_BATCHDELETEPLAYLISTSREQUEST'].fields_by_name['playlist_ids']._serialized_options = b'\202\3101\0051-100\212\3101\004<=50'
  _globals['_GETPLAYLISTPLAYERURLREQUEST'].fields_by_name['playlist_id']._loaded_options = None
  _globals['_GETPLAYLISTPLAYERURLREQUEST'].fields_by_name['playlist_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PLAYLISTSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_PLAYLISTSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002#\022!/video/v1/playlists/{playlist_id}'
  _globals['_PLAYLISTSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_PLAYLISTSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\025\022\023/video/v1/playlists'
  _globals['_PLAYLISTSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_PLAYLISTSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreatePlaylistMetadata\022\010Playlist\202\323\344\223\002\030\"\023/video/v1/playlists:\001*'
  _globals['_PLAYLISTSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_PLAYLISTSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdatePlaylistMetadata\022\010Playlist\202\323\344\223\002&2!/video/v1/playlists/{playlist_id}:\001*'
  _globals['_PLAYLISTSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_PLAYLISTSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeletePlaylistMetadata\022\025google.protobuf.Empty\202\323\344\223\002#*!/video/v1/playlists/{playlist_id}'
  _globals['_PLAYLISTSERVICE'].methods_by_name['BatchDelete']._loaded_options = None
  _globals['_PLAYLISTSERVICE'].methods_by_name['BatchDelete']._serialized_options = b'\262\322*5\n\034BatchDeletePlaylistsMetadata\022\025google.protobuf.Empty\202\323\344\223\002$\"\037/video/v1/playlists:batchDelete:\001*'
  _globals['_PLAYLISTSERVICE'].methods_by_name['GetPlayerURL']._loaded_options = None
  _globals['_PLAYLISTSERVICE'].methods_by_name['GetPlayerURL']._serialized_options = b'\202\323\344\223\0020\022./video/v1/playlists/{playlist_id}:getPlayerURL'
  _globals['_GETPLAYLISTREQUEST']._serialized_start=278
  _globals['_GETPLAYLISTREQUEST']._serialized_end=333
  _globals['_LISTPLAYLISTSREQUEST']._serialized_start=336
  _globals['_LISTPLAYLISTSREQUEST']._serialized_end=507
  _globals['_LISTPLAYLISTSRESPONSE']._serialized_start=509
  _globals['_LISTPLAYLISTSRESPONSE']._serialized_end=615
  _globals['_CREATEPLAYLISTREQUEST']._serialized_start=618
  _globals['_CREATEPLAYLISTREQUEST']._serialized_end=790
  _globals['_CREATEPLAYLISTMETADATA']._serialized_start=792
  _globals['_CREATEPLAYLISTMETADATA']._serialized_end=837
  _globals['_UPDATEPLAYLISTREQUEST']._serialized_start=840
  _globals['_UPDATEPLAYLISTREQUEST']._serialized_end=1063
  _globals['_UPDATEPLAYLISTMETADATA']._serialized_start=1065
  _globals['_UPDATEPLAYLISTMETADATA']._serialized_end=1110
  _globals['_DELETEPLAYLISTREQUEST']._serialized_start=1112
  _globals['_DELETEPLAYLISTREQUEST']._serialized_end=1170
  _globals['_DELETEPLAYLISTMETADATA']._serialized_start=1172
  _globals['_DELETEPLAYLISTMETADATA']._serialized_end=1217
  _globals['_BATCHDELETEPLAYLISTSREQUEST']._serialized_start=1219
  _globals['_BATCHDELETEPLAYLISTSREQUEST']._serialized_end=1323
  _globals['_BATCHDELETEPLAYLISTSMETADATA']._serialized_start=1325
  _globals['_BATCHDELETEPLAYLISTSMETADATA']._serialized_end=1377
  _globals['_GETPLAYLISTPLAYERURLREQUEST']._serialized_start=1379
  _globals['_GETPLAYLISTPLAYERURLREQUEST']._serialized_end=1504
  _globals['_PLAYLISTPLAYERPARAMS']._serialized_start=1506
  _globals['_PLAYLISTPLAYERPARAMS']._serialized_end=1576
  _globals['_GETPLAYLISTPLAYERURLRESPONSE']._serialized_start=1578
  _globals['_GETPLAYLISTPLAYERURLRESPONSE']._serialized_end=1642
  _globals['_PLAYLISTSERVICE']._serialized_start=1645
  _globals['_PLAYLISTSERVICE']._serialized_end=2822
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.logging.v1.log_entry_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LogOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    MIN_LEVEL_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    log_group_id: builtins.str
    """Entry will be written to log group resolved by ID."""
    folder_id: builtins.str
    """Entry will be written to default log group for specified folder."""
    min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType
    """Minimum log entry level.

    See [LogLevel.Level] for details.
    """
    service_account_id: builtins.str
    """Service account, which has permission to write to destination"""
    def __init__(
        self,
        *,
        log_group_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id", "min_level", b"min_level", "service_account_id", b"service_account_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["log_group_id", "folder_id"] | None: ...

global___LogOptions = LogOptions

@typing.final
class Bus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Bus._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Bus._Status.ValueType  # 0
        CREATING: Bus._Status.ValueType  # 1
        ACTIVE: Bus._Status.ValueType  # 2
        DELETING: Bus._Status.ValueType  # 3

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Bus.Status.ValueType  # 0
    CREATING: Bus.Status.ValueType  # 1
    ACTIVE: Bus.Status.ValueType  # 2
    DELETING: Bus.Status.ValueType  # 3

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    LOGGING_ENABLED_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the bus."""
    folder_id: builtins.str
    """ID of the folder that the bus belongs to."""
    cloud_id: builtins.str
    """ID of the cloud that the bus resides in."""
    name: builtins.str
    """Name of the bus."""
    description: builtins.str
    """Description of the bus."""
    deletion_protection: builtins.bool
    """Deletion protection."""
    status: global___Bus.Status.ValueType
    """Status of the bus."""
    logging_enabled: builtins.bool
    """Is logging from the bus enabled."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def log_options(self) -> global___LogOptions:
        """Options for logging from the bus."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        status: global___Bus.Status.ValueType = ...,
        logging_enabled: builtins.bool = ...,
        log_options: global___LogOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "log_options", b"log_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "log_options", b"log_options", "logging_enabled", b"logging_enabled", "name", b"name", "status", b"status"]) -> None: ...

global___Bus = Bus



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class HelmRelease(google.protobuf.message.Message):
    """A Helm Release."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[HelmRelease._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: HelmRelease._Status.ValueType  # 0
        UNKNOWN: HelmRelease._Status.ValueType  # 1
        """Helm release status is unknown"""
        DEPLOYED: HelmRelease._Status.ValueType  # 2
        """Helm release deployed."""
        UNINSTALLED: HelmRelease._Status.ValueType  # 3
        """Helm release uninstalled."""
        SUPERSEDED: HelmRelease._Status.ValueType  # 4
        """Helm release superseded."""
        FAILED: HelmRelease._Status.ValueType  # 5
        """Helm release installation failed."""
        UNINSTALLING: HelmRelease._Status.ValueType  # 6
        """Helm release is being uninstalled."""
        PENDING_INSTALL: HelmRelease._Status.ValueType  # 7
        """Helm release is to be installed."""
        PENDING_UPGRADE: HelmRelease._Status.ValueType  # 8
        """Helm release is to be updated."""
        PENDING_ROLLBACK: HelmRelease._Status.ValueType  # 9
        """Helm release is to be rolled back."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: HelmRelease.Status.ValueType  # 0
    UNKNOWN: HelmRelease.Status.ValueType  # 1
    """Helm release status is unknown"""
    DEPLOYED: HelmRelease.Status.ValueType  # 2
    """Helm release deployed."""
    UNINSTALLED: HelmRelease.Status.ValueType  # 3
    """Helm release uninstalled."""
    SUPERSEDED: HelmRelease.Status.ValueType  # 4
    """Helm release superseded."""
    FAILED: HelmRelease.Status.ValueType  # 5
    """Helm release installation failed."""
    UNINSTALLING: HelmRelease.Status.ValueType  # 6
    """Helm release is being uninstalled."""
    PENDING_INSTALL: HelmRelease.Status.ValueType  # 7
    """Helm release is to be installed."""
    PENDING_UPGRADE: HelmRelease.Status.ValueType  # 8
    """Helm release is to be updated."""
    PENDING_ROLLBACK: HelmRelease.Status.ValueType  # 9
    """Helm release is to be rolled back."""

    ID_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    APP_NAME_FIELD_NUMBER: builtins.int
    APP_NAMESPACE_FIELD_NUMBER: builtins.int
    PRODUCT_ID_FIELD_NUMBER: builtins.int
    PRODUCT_NAME_FIELD_NUMBER: builtins.int
    PRODUCT_VERSION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of a helm release."""
    cluster_id: builtins.str
    """ID of the Kubernetes cluster."""
    app_name: builtins.str
    """Name of the application."""
    app_namespace: builtins.str
    """Namespace of the application."""
    product_id: builtins.str
    """Kubernetes marketplace product id."""
    product_name: builtins.str
    """Kubernetes marketplace product name."""
    product_version: builtins.str
    """Kubernetes marketplace product version."""
    status: global___HelmRelease.Status.ValueType
    """Status of a helm release."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        cluster_id: builtins.str = ...,
        app_name: builtins.str = ...,
        app_namespace: builtins.str = ...,
        product_id: builtins.str = ...,
        product_name: builtins.str = ...,
        product_version: builtins.str = ...,
        status: global___HelmRelease.Status.ValueType = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["app_name", b"app_name", "app_namespace", b"app_namespace", "cluster_id", b"cluster_id", "created_at", b"created_at", "id", b"id", "product_id", b"product_id", "product_name", b"product_name", "product_version", b"product_version", "status", b"status"]) -> None: ...

global___HelmRelease = HelmRelease



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.loadbalancer.v1.network_load_balancer_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetNetworkLoadBalancerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the NetworkLoadBalancer resource to return.
    To get the network load balancer ID, use a [NetworkLoadBalancerService.List] request.
    """
    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_load_balancer_id", b"network_load_balancer_id"]) -> None: ...

global___GetNetworkLoadBalancerRequest = GetNetworkLoadBalancerRequest

@typing.final
class ListNetworkLoadBalancersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that the network load balancer belongs to.
    To get the folder ID, use a [NetworkLoadBalancerService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [<ResponseMessage>.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListNetworkLoadBalancersResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can only filter by the [NetworkLoadBalancer.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListNetworkLoadBalancersRequest = ListNetworkLoadBalancersRequest

@typing.final
class ListNetworkLoadBalancersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListNetworkLoadBalancersRequest.page_size], use
    the [next_page_token] as the value
    for the [ListNetworkLoadBalancersRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def network_load_balancers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.NetworkLoadBalancer]:
        """List of NetworkLoadBalancer resources."""

    def __init__(
        self,
        *,
        network_load_balancers: collections.abc.Iterable[yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.NetworkLoadBalancer] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_load_balancers", b"network_load_balancers", "next_page_token", b"next_page_token"]) -> None: ...

global___ListNetworkLoadBalancersResponse = ListNetworkLoadBalancersResponse

@typing.final
class CreateNetworkLoadBalancerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    REGION_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    LISTENER_SPECS_FIELD_NUMBER: builtins.int
    ATTACHED_TARGET_GROUPS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    ALLOW_ZONAL_SHIFT_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a network load balancer in.
    To get the folder ID, use a [NetworkLoadBalancerService.List] request.
    """
    name: builtins.str
    """Name of the network load balancer.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the network load balancer."""
    region_id: builtins.str
    """ID of the region where the network load balancer resides."""
    type: yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.NetworkLoadBalancer.Type.ValueType
    """Type of the network load balancer."""
    deletion_protection: builtins.bool
    """Specifies if network load balancer protected from deletion."""
    allow_zonal_shift: builtins.bool
    """Specifies if network load balancer available to zonal shift."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs."""

    @property
    def listener_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListenerSpec]:
        """List of listeners and their specs for the network load balancer."""

    @property
    def attached_target_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.AttachedTargetGroup]:
        """List of attached target groups for the network load balancer."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        region_id: builtins.str = ...,
        type: yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.NetworkLoadBalancer.Type.ValueType = ...,
        listener_specs: collections.abc.Iterable[global___ListenerSpec] | None = ...,
        attached_target_groups: collections.abc.Iterable[yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.AttachedTargetGroup] | None = ...,
        deletion_protection: builtins.bool = ...,
        allow_zonal_shift: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["allow_zonal_shift", b"allow_zonal_shift", "attached_target_groups", b"attached_target_groups", "deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "listener_specs", b"listener_specs", "name", b"name", "region_id", b"region_id", "type", b"type"]) -> None: ...

global___CreateNetworkLoadBalancerRequest = CreateNetworkLoadBalancerRequest

@typing.final
class CreateNetworkLoadBalancerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the network load balancer that is being created."""
    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_load_balancer_id", b"network_load_balancer_id"]) -> None: ...

global___CreateNetworkLoadBalancerMetadata = CreateNetworkLoadBalancerMetadata

@typing.final
class UpdateNetworkLoadBalancerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LISTENER_SPECS_FIELD_NUMBER: builtins.int
    ATTACHED_TARGET_GROUPS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    ALLOW_ZONAL_SHIFT_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the network load balancer to update.
    To get the network load balancer ID, use a [NetworkLoadBalancerService.List] request.
    """
    name: builtins.str
    """Name of the network load balancer.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the network load balancer."""
    deletion_protection: builtins.bool
    """Specifies if network load balancer protected from deletion."""
    allow_zonal_shift: builtins.bool
    """Specifies if network load balancer available to zonal shift."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the NetworkLoadBalancer resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs.

        The existing set of `` labels `` is completely replaced with the provided set.
        """

    @property
    def listener_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListenerSpec]:
        """A list of listeners and their specs for the network load balancer."""

    @property
    def attached_target_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.AttachedTargetGroup]:
        """A list of attached target groups for the network load balancer."""

    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        listener_specs: collections.abc.Iterable[global___ListenerSpec] | None = ...,
        attached_target_groups: collections.abc.Iterable[yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.AttachedTargetGroup] | None = ...,
        deletion_protection: builtins.bool = ...,
        allow_zonal_shift: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allow_zonal_shift", b"allow_zonal_shift", "attached_target_groups", b"attached_target_groups", "deletion_protection", b"deletion_protection", "description", b"description", "labels", b"labels", "listener_specs", b"listener_specs", "name", b"name", "network_load_balancer_id", b"network_load_balancer_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateNetworkLoadBalancerRequest = UpdateNetworkLoadBalancerRequest

@typing.final
class UpdateNetworkLoadBalancerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the NetworkLoadBalancer resource that is being updated."""
    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_load_balancer_id", b"network_load_balancer_id"]) -> None: ...

global___UpdateNetworkLoadBalancerMetadata = UpdateNetworkLoadBalancerMetadata

@typing.final
class DeleteNetworkLoadBalancerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the network load balancer to delete.
    To get the network load balancer ID, use a [NetworkLoadBalancerService.List] request.
    """
    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_load_balancer_id", b"network_load_balancer_id"]) -> None: ...

global___DeleteNetworkLoadBalancerRequest = DeleteNetworkLoadBalancerRequest

@typing.final
class DeleteNetworkLoadBalancerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the NetworkLoadBalancer resource that is being deleted."""
    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_load_balancer_id", b"network_load_balancer_id"]) -> None: ...

global___DeleteNetworkLoadBalancerMetadata = DeleteNetworkLoadBalancerMetadata

@typing.final
class StartNetworkLoadBalancerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the network load balancer to start.
    To get the network load balancer ID, use a [NetworkLoadBalancerService.List] request.
    """
    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_load_balancer_id", b"network_load_balancer_id"]) -> None: ...

global___StartNetworkLoadBalancerRequest = StartNetworkLoadBalancerRequest

@typing.final
class StartNetworkLoadBalancerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the NetworkLoadBalancer resource that is being started."""
    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_load_balancer_id", b"network_load_balancer_id"]) -> None: ...

global___StartNetworkLoadBalancerMetadata = StartNetworkLoadBalancerMetadata

@typing.final
class StopNetworkLoadBalancerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the network load balancer to stop.
    To get the network load balancer ID, use a [NetworkLoadBalancerService.List] request.
    """
    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_load_balancer_id", b"network_load_balancer_id"]) -> None: ...

global___StopNetworkLoadBalancerRequest = StopNetworkLoadBalancerRequest

@typing.final
class StopNetworkLoadBalancerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the NetworkLoadBalancer resource that is being stopped."""
    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_load_balancer_id", b"network_load_balancer_id"]) -> None: ...

global___StopNetworkLoadBalancerMetadata = StopNetworkLoadBalancerMetadata

@typing.final
class AttachNetworkLoadBalancerTargetGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    ATTACHED_TARGET_GROUP_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the network load balancer to attach the target group to.
    To get the network load balancer ID, use a [NetworkLoadBalancerService.List] request.
    """
    @property
    def attached_target_group(self) -> yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.AttachedTargetGroup:
        """ID of the attached target group to attach to the network load balancer.
        To get the network load balancer ID, use a [NetworkLoadBalancerService.List] request.
        """

    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
        attached_target_group: yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.AttachedTargetGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attached_target_group", b"attached_target_group"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attached_target_group", b"attached_target_group", "network_load_balancer_id", b"network_load_balancer_id"]) -> None: ...

global___AttachNetworkLoadBalancerTargetGroupRequest = AttachNetworkLoadBalancerTargetGroupRequest

@typing.final
class AttachNetworkLoadBalancerTargetGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    TARGET_GROUP_ID_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the network load balancer that the target group is being attached to."""
    target_group_id: builtins.str
    """ID of the target group."""
    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
        target_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_load_balancer_id", b"network_load_balancer_id", "target_group_id", b"target_group_id"]) -> None: ...

global___AttachNetworkLoadBalancerTargetGroupMetadata = AttachNetworkLoadBalancerTargetGroupMetadata

@typing.final
class DetachNetworkLoadBalancerTargetGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    TARGET_GROUP_ID_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the network load balancer to detach the target group from.
    To get the network load balancer ID, use a [NetworkLoadBalancerService.List] request.
    """
    target_group_id: builtins.str
    """ID of the target group."""
    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
        target_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_load_balancer_id", b"network_load_balancer_id", "target_group_id", b"target_group_id"]) -> None: ...

global___DetachNetworkLoadBalancerTargetGroupRequest = DetachNetworkLoadBalancerTargetGroupRequest

@typing.final
class DetachNetworkLoadBalancerTargetGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    TARGET_GROUP_ID_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the network load balancer that the target group is being detached from."""
    target_group_id: builtins.str
    """ID of the target group."""
    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
        target_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_load_balancer_id", b"network_load_balancer_id", "target_group_id", b"target_group_id"]) -> None: ...

global___DetachNetworkLoadBalancerTargetGroupMetadata = DetachNetworkLoadBalancerTargetGroupMetadata

@typing.final
class AddNetworkLoadBalancerListenerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    LISTENER_SPEC_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the network load balancer to add a listener to.
    To get the network load balancer ID, use a [NetworkLoadBalancerService.List] request.
    """
    @property
    def listener_spec(self) -> global___ListenerSpec:
        """Listener spec."""

    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
        listener_spec: global___ListenerSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["listener_spec", b"listener_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["listener_spec", b"listener_spec", "network_load_balancer_id", b"network_load_balancer_id"]) -> None: ...

global___AddNetworkLoadBalancerListenerRequest = AddNetworkLoadBalancerListenerRequest

@typing.final
class AddNetworkLoadBalancerListenerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the network load balancer that the listener is being added to."""
    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_load_balancer_id", b"network_load_balancer_id"]) -> None: ...

global___AddNetworkLoadBalancerListenerMetadata = AddNetworkLoadBalancerListenerMetadata

@typing.final
class RemoveNetworkLoadBalancerListenerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    LISTENER_NAME_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the network load balancer to remove the listener from.
    To get the network load balancer ID, use a [NetworkLoadBalancerService.List] request.
    """
    listener_name: builtins.str
    """Name of the listener to delete."""
    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
        listener_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["listener_name", b"listener_name", "network_load_balancer_id", b"network_load_balancer_id"]) -> None: ...

global___RemoveNetworkLoadBalancerListenerRequest = RemoveNetworkLoadBalancerListenerRequest

@typing.final
class RemoveNetworkLoadBalancerListenerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the network load balancer that the listener is being removed from."""
    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_load_balancer_id", b"network_load_balancer_id"]) -> None: ...

global___RemoveNetworkLoadBalancerListenerMetadata = RemoveNetworkLoadBalancerListenerMetadata

@typing.final
class ListNetworkLoadBalancerOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the NetworkLoadBalancer resource to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than [page_size], the service returns a [ListNetworkLoadBalancerOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListNetworkLoadBalancerOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_load_balancer_id", b"network_load_balancer_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListNetworkLoadBalancerOperationsRequest = ListNetworkLoadBalancerOperationsRequest

@typing.final
class ListNetworkLoadBalancerOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListNetworkLoadBalancerOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListNetworkLoadBalancerOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified network load balancer."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListNetworkLoadBalancerOperationsResponse = ListNetworkLoadBalancerOperationsResponse

@typing.final
class GetTargetStatesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_LOAD_BALANCER_ID_FIELD_NUMBER: builtins.int
    TARGET_GROUP_ID_FIELD_NUMBER: builtins.int
    network_load_balancer_id: builtins.str
    """ID of the NetworkLoadBalancer resource with an attached target group."""
    target_group_id: builtins.str
    """ID of the target group to get states of resources from."""
    def __init__(
        self,
        *,
        network_load_balancer_id: builtins.str = ...,
        target_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_load_balancer_id", b"network_load_balancer_id", "target_group_id", b"target_group_id"]) -> None: ...

global___GetTargetStatesRequest = GetTargetStatesRequest

@typing.final
class GetTargetStatesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_STATES_FIELD_NUMBER: builtins.int
    @property
    def target_states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.TargetState]:
        """List of states of targets within the target group that is specified in the [GetTargetStatesRequest] message."""

    def __init__(
        self,
        *,
        target_states: collections.abc.Iterable[yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.TargetState] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["target_states", b"target_states"]) -> None: ...

global___GetTargetStatesResponse = GetTargetStatesResponse

@typing.final
class ExternalAddressSpec(google.protobuf.message.Message):
    """External address specification that is used by [ListenerSpec]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    IP_VERSION_FIELD_NUMBER: builtins.int
    address: builtins.str
    """Public IP address for a listener.
    If you provide a static public IP address for the [NetworkLoadBalancerService.Update]
    method, it will replace the existing listener address.
    """
    ip_version: yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.IpVersion.ValueType
    """IP version."""
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        ip_version: yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.IpVersion.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "ip_version", b"ip_version"]) -> None: ...

global___ExternalAddressSpec = ExternalAddressSpec

@typing.final
class InternalAddressSpec(google.protobuf.message.Message):
    """Internal address specification that is used by [ListenerSpec]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    IP_VERSION_FIELD_NUMBER: builtins.int
    address: builtins.str
    """Internal IP address for a listener."""
    subnet_id: builtins.str
    """ID of the subnet."""
    ip_version: yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.IpVersion.ValueType
    """IP version."""
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        subnet_id: builtins.str = ...,
        ip_version: yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.IpVersion.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "ip_version", b"ip_version", "subnet_id", b"subnet_id"]) -> None: ...

global___InternalAddressSpec = InternalAddressSpec

@typing.final
class ListenerSpec(google.protobuf.message.Message):
    """Listener specification that will be used by a network load balancer."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    EXTERNAL_ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    INTERNAL_ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    TARGET_PORT_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the listener. The name must be unique for each listener on a single load balancer. 3-63 characters long."""
    port: builtins.int
    """Port for incoming traffic."""
    protocol: yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.Listener.Protocol.ValueType
    """Protocol for incoming traffic."""
    target_port: builtins.int
    """Port of a target.
    Acceptable values are 1 to 65535, inclusive.
    """
    @property
    def external_address_spec(self) -> global___ExternalAddressSpec:
        """External IP address specification."""

    @property
    def internal_address_spec(self) -> global___InternalAddressSpec:
        """Internal IP address specification."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        port: builtins.int = ...,
        protocol: yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.Listener.Protocol.ValueType = ...,
        external_address_spec: global___ExternalAddressSpec | None = ...,
        internal_address_spec: global___InternalAddressSpec | None = ...,
        target_port: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["address", b"address", "external_address_spec", b"external_address_spec", "internal_address_spec", b"internal_address_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "external_address_spec", b"external_address_spec", "internal_address_spec", b"internal_address_spec", "name", b"name", "port", b"port", "protocol", b"protocol", "target_port", b"target_port"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["address", b"address"]) -> typing.Literal["external_address_spec", "internal_address_spec"] | None: ...

global___ListenerSpec = ListenerSpec



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.operation.operation_pb2
import yandex.cloud.video.v1.channel_pb2
import yandex.cloud.video.v1.channel_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ChannelServiceStub:
    """Channel management service."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.channel_service_pb2.GetChannelRequest,
        yandex.cloud.video.v1.channel_pb2.Channel,
    ]
    """Get the specific channel."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.channel_service_pb2.ListChannelsRequest,
        yandex.cloud.video.v1.channel_service_pb2.ListChannelsResponse,
    ]
    """List channels for organization."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.channel_service_pb2.CreateChannelRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create channel."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.channel_service_pb2.UpdateChannelRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update channel."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.channel_service_pb2.DeleteChannelRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete channel."""

    BatchDelete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.channel_service_pb2.BatchDeleteChannelsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Batch delete channels."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """List existing access bindings for the specified channel."""

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Set access bindings for the channel."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update access bindings for the specified channel."""

class ChannelServiceAsyncStub:
    """Channel management service."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.channel_service_pb2.GetChannelRequest,
        yandex.cloud.video.v1.channel_pb2.Channel,
    ]
    """Get the specific channel."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.channel_service_pb2.ListChannelsRequest,
        yandex.cloud.video.v1.channel_service_pb2.ListChannelsResponse,
    ]
    """List channels for organization."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.channel_service_pb2.CreateChannelRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create channel."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.channel_service_pb2.UpdateChannelRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update channel."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.channel_service_pb2.DeleteChannelRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete channel."""

    BatchDelete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.channel_service_pb2.BatchDeleteChannelsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Batch delete channels."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """List existing access bindings for the specified channel."""

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Set access bindings for the channel."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update access bindings for the specified channel."""

class ChannelServiceServicer(metaclass=abc.ABCMeta):
    """Channel management service."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.video.v1.channel_service_pb2.GetChannelRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.channel_pb2.Channel, collections.abc.Awaitable[yandex.cloud.video.v1.channel_pb2.Channel]]:
        """Get the specific channel."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.video.v1.channel_service_pb2.ListChannelsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.channel_service_pb2.ListChannelsResponse, collections.abc.Awaitable[yandex.cloud.video.v1.channel_service_pb2.ListChannelsResponse]]:
        """List channels for organization."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.video.v1.channel_service_pb2.CreateChannelRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Create channel."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.video.v1.channel_service_pb2.UpdateChannelRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Update channel."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.video.v1.channel_service_pb2.DeleteChannelRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete channel."""

    @abc.abstractmethod
    def BatchDelete(
        self,
        request: yandex.cloud.video.v1.channel_service_pb2.BatchDeleteChannelsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Batch delete channels."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """List existing access bindings for the specified channel."""

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Set access bindings for the channel."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Update access bindings for the specified channel."""

def add_ChannelServiceServicer_to_server(servicer: ChannelServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/api/v1/regression/widget.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/api/v1/regression/widget.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.loadtesting.api.v1.report import kpi_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_report_dot_kpi__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7yandex/cloud/loadtesting/api/v1/regression/widget.proto\x12*yandex.cloud.loadtesting.api.v1.regression\x1a\x30yandex/cloud/loadtesting/api/v1/report/kpi.proto\"\x8a\x03\n\x06Widget\x12S\n\x08position\x18\x01 \x01(\x0b\x32\x41.yandex.cloud.loadtesting.api.v1.regression.Widget.LayoutPosition\x12H\n\x05\x63hart\x18\x02 \x01(\x0b\x32\x37.yandex.cloud.loadtesting.api.v1.regression.ChartWidgetH\x00\x12\x46\n\x04text\x18\x03 \x01(\x0b\x32\x36.yandex.cloud.loadtesting.api.v1.regression.TextWidgetH\x00\x12H\n\x05title\x18\x04 \x01(\x0b\x32\x37.yandex.cloud.loadtesting.api.v1.regression.TitleWidgetH\x00\x1a\x45\n\x0eLayoutPosition\x12\t\n\x01x\x18\x01 \x01(\x03\x12\t\n\x01y\x18\x02 \x01(\x03\x12\r\n\x05width\x18\x03 \x01(\x03\x12\x0e\n\x06height\x18\x04 \x01(\x03\x42\x08\n\x06widget\"\x9e\x01\n\x0b\x43hartWidget\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nfilter_str\x18\x04 \x01(\t\x12\x11\n\ttest_case\x18\x05 \x01(\t\x12\x39\n\x04kpis\x18\x06 \x03(\x0b\x32+.yandex.cloud.loadtesting.api.v1.report.Kpi\"\x1a\n\nTextWidget\x12\x0c\n\x04text\x18\x01 \x01(\t\"\xde\x01\n\x0bTitleWidget\x12\x0c\n\x04text\x18\x01 \x01(\t\x12O\n\x04size\x18\x02 \x01(\x0e\x32\x41.yandex.cloud.loadtesting.api.v1.regression.TitleWidget.TitleSize\"p\n\tTitleSize\x12\x1a\n\x16TITLE_SIZE_UNSPECIFIED\x10\x00\x12\x11\n\rTITLE_SIZE_XS\x10\x01\x12\x10\n\x0cTITLE_SIZE_S\x10\x02\x12\x10\n\x0cTITLE_SIZE_M\x10\x03\x12\x10\n\x0cTITLE_SIZE_L\x10\x04\x42\x8b\x01\n.yandex.cloud.api.loadtesting.api.v1.regressionZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/regression;regressionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.regression.widget_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n.yandex.cloud.api.loadtesting.api.v1.regressionZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/regression;regression'
  _globals['_WIDGET']._serialized_start=154
  _globals['_WIDGET']._serialized_end=548
  _globals['_WIDGET_LAYOUTPOSITION']._serialized_start=469
  _globals['_WIDGET_LAYOUTPOSITION']._serialized_end=538
  _globals['_CHARTWIDGET']._serialized_start=551
  _globals['_CHARTWIDGET']._serialized_end=709
  _globals['_TEXTWIDGET']._serialized_start=711
  _globals['_TEXTWIDGET']._serialized_end=737
  _globals['_TITLEWIDGET']._serialized_start=740
  _globals['_TITLEWIDGET']._serialized_end=962
  _globals['_TITLEWIDGET_TITLESIZE']._serialized_start=850
  _globals['_TITLEWIDGET_TITLESIZE']._serialized_end=962
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/quotamanager/v1/quota_limit_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/quotamanager/v1/quota_limit_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.quotamanager.v1 import resource_pb2 as yandex_dot_cloud_dot_quotamanager_dot_v1_dot_resource__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/quotamanager/v1/quota_limit_service.proto\x12\x1cyandex.cloud.quotamanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a+yandex/cloud/quotamanager/v1/resource.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1egoogle/protobuf/wrappers.proto\"v\n\x14GetQuotaLimitRequest\x12>\n\x08resource\x18\x01 \x01(\x0b\x32&.yandex.cloud.quotamanager.v1.ResourceB\x04\xe8\xc7\x31\x01\x12\x1e\n\x08quota_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\"\xae\x01\n\x16ListQuotaLimitsRequest\x12>\n\x08resource\x18\x01 \x01(\x0b\x32&.yandex.cloud.quotamanager.v1.ResourceB\x04\xe8\xc7\x31\x01\x12\x15\n\x07service\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"\xac\x01\n\x17ListQuotaLimitsResponse\x12\x38\n\x08resource\x18\x01 \x01(\x0b\x32&.yandex.cloud.quotamanager.v1.Resource\x12>\n\x0cquota_limits\x18\x02 \x03(\x0b\x32(.yandex.cloud.quotamanager.v1.QuotaLimit\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\"q\n\x13ListServicesRequest\x12\x1b\n\rresource_type\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"h\n\x14ListServicesResponse\x12\x37\n\x08services\x18\x01 \x03(\x0b\x32%.yandex.cloud.quotamanager.v1.Service\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"x\n\nQuotaLimit\x12\x10\n\x08quota_id\x18\x01 \x01(\t\x12+\n\x05limit\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x05usage\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"#\n\x07Service\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xf0\x03\n\x11QuotaLimitService\x12\x95\x01\n\x03Get\x12\x32.yandex.cloud.quotamanager.v1.GetQuotaLimitRequest\x1a(.yandex.cloud.quotamanager.v1.QuotaLimit\"0\x82\xd3\xe4\x93\x02*\x12(/quota-manager/v1/quotaLimits/{quota_id}\x12\x9a\x01\n\x04List\x12\x34.yandex.cloud.quotamanager.v1.ListQuotaLimitsRequest\x1a\x35.yandex.cloud.quotamanager.v1.ListQuotaLimitsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/quota-manager/v1/quotaLimits\x12\xa5\x01\n\x0cListServices\x12\x31.yandex.cloud.quotamanager.v1.ListServicesRequest\x1a\x32.yandex.cloud.quotamanager.v1.ListServicesResponse\".\x82\xd3\xe4\x93\x02(\x12&/quota-manager/v1/quotaLimits/servicesBq\n yandex.cloud.api.quotamanager.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/quotamanager/v1;quotamanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.quotamanager.v1.quota_limit_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n yandex.cloud.api.quotamanager.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/quotamanager/v1;quotamanager'
  _globals['_GETQUOTALIMITREQUEST'].fields_by_name['resource']._loaded_options = None
  _globals['_GETQUOTALIMITREQUEST'].fields_by_name['resource']._serialized_options = b'\350\3071\001'
  _globals['_GETQUOTALIMITREQUEST'].fields_by_name['quota_id']._loaded_options = None
  _globals['_GETQUOTALIMITREQUEST'].fields_by_name['quota_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _globals['_LISTQUOTALIMITSREQUEST'].fields_by_name['resource']._loaded_options = None
  _globals['_LISTQUOTALIMITSREQUEST'].fields_by_name['resource']._serialized_options = b'\350\3071\001'
  _globals['_LISTQUOTALIMITSREQUEST'].fields_by_name['service']._loaded_options = None
  _globals['_LISTQUOTALIMITSREQUEST'].fields_by_name['service']._serialized_options = b'\350\3071\001'
  _globals['_LISTQUOTALIMITSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTQUOTALIMITSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTQUOTALIMITSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTQUOTALIMITSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTSERVICESREQUEST'].fields_by_name['resource_type']._loaded_options = None
  _globals['_LISTSERVICESREQUEST'].fields_by_name['resource_type']._serialized_options = b'\350\3071\001'
  _globals['_LISTSERVICESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSERVICESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTSERVICESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSERVICESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_QUOTALIMITSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_QUOTALIMITSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002*\022(/quota-manager/v1/quotaLimits/{quota_id}'
  _globals['_QUOTALIMITSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_QUOTALIMITSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\037\022\035/quota-manager/v1/quotaLimits'
  _globals['_QUOTALIMITSERVICE'].methods_by_name['ListServices']._loaded_options = None
  _globals['_QUOTALIMITSERVICE'].methods_by_name['ListServices']._serialized_options = b'\202\323\344\223\002(\022&/quota-manager/v1/quotaLimits/services'
  _globals['_GETQUOTALIMITREQUEST']._serialized_start=226
  _globals['_GETQUOTALIMITREQUEST']._serialized_end=344
  _globals['_LISTQUOTALIMITSREQUEST']._serialized_start=347
  _globals['_LISTQUOTALIMITSREQUEST']._serialized_end=521
  _globals['_LISTQUOTALIMITSRESPONSE']._serialized_start=524
  _globals['_LISTQUOTALIMITSRESPONSE']._serialized_end=696
  _globals['_LISTSERVICESREQUEST']._serialized_start=698
  _globals['_LISTSERVICESREQUEST']._serialized_end=811
  _globals['_LISTSERVICESRESPONSE']._serialized_start=813
  _globals['_LISTSERVICESRESPONSE']._serialized_end=917
  _globals['_QUOTALIMIT']._serialized_start=919
  _globals['_QUOTALIMIT']._serialized_end=1039
  _globals['_SERVICE']._serialized_start=1041
  _globals['_SERVICE']._serialized_end=1076
  _globals['_QUOTALIMITSERVICE']._serialized_start=1079
  _globals['_QUOTALIMITSERVICE']._serialized_end=1575
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.apploadbalancer.v1.virtual_host_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class HttpRouter(google.protobuf.message.Message):
    """An HTTP router resource.
    For details about the concept, see [documentation](/docs/application-load-balancer/concepts/http-router).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    VIRTUAL_HOSTS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    ROUTE_OPTIONS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the router. Generated at creation time."""
    name: builtins.str
    """Name of the router. The name is unique within the folder."""
    description: builtins.str
    """Description of the router."""
    folder_id: builtins.str
    """ID of the folder that the router belongs to."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Router labels as `key:value` pairs.
        For details about the concept, see [documentation](/docs/overview/concepts/services#labels).
        """

    @property
    def virtual_hosts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.VirtualHost]:
        """Virtual hosts that combine routes inside the router.
        For details about the concept, see [documentation](/docs/application-load-balancer/concepts/http-router#virtual-host).

        Only one virtual host with no authority (default match) can be specified.
        """

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def route_options(self) -> yandex.cloud.apploadbalancer.v1.virtual_host_pb2.RouteOptions: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        folder_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        virtual_hosts: collections.abc.Iterable[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.VirtualHost] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        route_options: yandex.cloud.apploadbalancer.v1.virtual_host_pb2.RouteOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "route_options", b"route_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "route_options", b"route_options", "virtual_hosts", b"virtual_hosts"]) -> None: ...

global___HttpRouter = HttpRouter



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/smartwebsecurity/v1/waf/rule_set_descriptor.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/smartwebsecurity/v1/waf/rule_set_descriptor.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>yandex/cloud/smartwebsecurity/v1/waf/rule_set_descriptor.proto\x12$yandex.cloud.smartwebsecurity.v1.waf\x1a\x1dyandex/cloud/validation.proto\"\xa0\x02\n\x11RuleSetDescriptor\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x15\n\x07version\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x10\n\x02id\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12V\n\x05rules\x18\x04 \x03(\x0b\x32G.yandex.cloud.smartwebsecurity.v1.waf.RuleSetDescriptor.RuleDescription\x1av\n\x0fRuleDescription\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\ranomaly_score\x18\x08 \x01(\x03\x12\x16\n\x0eparanoia_level\x18\t \x01(\x03J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\n\x10\x0b\x42\x85\x01\n(yandex.cloud.api.smartwebsecurity.v1.wafZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1/waf;smartwebsecurityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.smartwebsecurity.v1.waf.rule_set_descriptor_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.smartwebsecurity.v1.wafZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1/waf;smartwebsecurity'
  _globals['_RULESETDESCRIPTOR'].fields_by_name['name']._loaded_options = None
  _globals['_RULESETDESCRIPTOR'].fields_by_name['name']._serialized_options = b'\350\3071\001'
  _globals['_RULESETDESCRIPTOR'].fields_by_name['version']._loaded_options = None
  _globals['_RULESETDESCRIPTOR'].fields_by_name['version']._serialized_options = b'\350\3071\001'
  _globals['_RULESETDESCRIPTOR'].fields_by_name['id']._loaded_options = None
  _globals['_RULESETDESCRIPTOR'].fields_by_name['id']._serialized_options = b'\350\3071\001'
  _globals['_RULESETDESCRIPTOR']._serialized_start=136
  _globals['_RULESETDESCRIPTOR']._serialized_end=424
  _globals['_RULESETDESCRIPTOR_RULEDESCRIPTION']._serialized_start=306
  _globals['_RULESETDESCRIPTOR_RULEDESCRIPTION']._serialized_end=424
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Playlist(google.protobuf.message.Message):
    """Entity representing an ordered list of videos or episodes."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the playlist."""
    channel_id: builtins.str
    """ID of the channel to create the playlist in."""
    title: builtins.str
    """Playlist title."""
    description: builtins.str
    """Playlist description."""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PlaylistItem]:
        """List of playlist items."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when playlist was created."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time of last playlist update."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        channel_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        items: collections.abc.Iterable[global___PlaylistItem] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "created_at", b"created_at", "description", b"description", "id", b"id", "items", b"items", "title", b"title", "updated_at", b"updated_at"]) -> None: ...

global___Playlist = Playlist

@typing.final
class PlaylistItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    EPISODE_ID_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video."""
    episode_id: builtins.str
    """ID of the episode."""
    position: builtins.int
    """Item position (zero-indexed)."""
    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
        episode_id: builtins.str = ...,
        position: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["episode_id", b"episode_id", "id", b"id", "video_id", b"video_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["episode_id", b"episode_id", "id", b"id", "position", b"position", "video_id", b"video_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["id", b"id"]) -> typing.Literal["video_id", "episode_id"] | None: ...

global___PlaylistItem = PlaylistItem



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ai.ocr.v1.ocr_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RecognizeTextRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    MIME_TYPE_FIELD_NUMBER: builtins.int
    LANGUAGE_CODES_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    content: builtins.bytes
    """Bytes with data"""
    mime_type: builtins.str
    """Specifications of the ([MIME type](https://en.wikipedia.org/wiki/Media_type)). Each specification contains the file to analyze and features to use for analysis. Restrictions:
    * Supported file formats: `JPEG`, `PNG`, `PDF`.
    * Maximum file size: see [documentation](/docs/vision/concepts/limits).
    * Image size should not exceed 20M pixels (length x width).
    * The number of pages in a PDF file should not exceed 1.
    """
    model: builtins.str
    """[Model](/docs/vision/concepts/ocr/template-recognition#models) to use for text detection."""
    @property
    def language_codes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """[List of the languages](/docs/vision/concepts/ocr/supported-languages) to recognize text.
        Specified in [ISO 639-1](https://en.wikipedia.org/wiki/ISO_639-1) format (for example, `ru`).
        """

    def __init__(
        self,
        *,
        content: builtins.bytes = ...,
        mime_type: builtins.str = ...,
        language_codes: collections.abc.Iterable[builtins.str] | None = ...,
        model: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["content", b"content", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "language_codes", b"language_codes", "mime_type", b"mime_type", "model", b"model", "source", b"source"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["source", b"source"]) -> typing.Literal["content"] | None: ...

global___RecognizeTextRequest = RecognizeTextRequest

@typing.final
class RecognizeTextResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_ANNOTATION_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    page: builtins.int
    """Page number in PDF file."""
    @property
    def text_annotation(self) -> yandex.cloud.ai.ocr.v1.ocr_pb2.TextAnnotation:
        """Recognized text blocks in page or text from entities."""

    def __init__(
        self,
        *,
        text_annotation: yandex.cloud.ai.ocr.v1.ocr_pb2.TextAnnotation | None = ...,
        page: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["text_annotation", b"text_annotation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["page", b"page", "text_annotation", b"text_annotation"]) -> None: ...

global___RecognizeTextResponse = RecognizeTextResponse

@typing.final
class GetRecognitionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATION_ID_FIELD_NUMBER: builtins.int
    operation_id: builtins.str
    """Operation ID of async recognition request."""
    def __init__(
        self,
        *,
        operation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["operation_id", b"operation_id"]) -> None: ...

global___GetRecognitionRequest = GetRecognitionRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.vpc.v1.security_group_pb2
import yandex.cloud.vpc.v1.security_group_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SecurityGroupServiceStub:
    """A set of methods for managing SecurityGroup resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.security_group_service_pb2.GetSecurityGroupRequest,
        yandex.cloud.vpc.v1.security_group_pb2.SecurityGroup,
    ]
    """Returns the specified SecurityGroup resource.

    To get the list of all available SecurityGroup resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.security_group_service_pb2.ListSecurityGroupsRequest,
        yandex.cloud.vpc.v1.security_group_service_pb2.ListSecurityGroupsResponse,
    ]
    """Retrieves the list of SecurityGroup resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.security_group_service_pb2.CreateSecurityGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a security group in the specified folder and network."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.security_group_service_pb2.UpdateSecurityGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified security group.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    UpdateRules: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.security_group_service_pb2.UpdateSecurityGroupRulesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the rules of the specified security group."""

    UpdateRule: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.security_group_service_pb2.UpdateSecurityGroupRuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified rule."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.security_group_service_pb2.DeleteSecurityGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified security group."""

    Move: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.security_group_service_pb2.MoveSecurityGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Moves security groups to another folder."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.security_group_service_pb2.ListSecurityGroupOperationsRequest,
        yandex.cloud.vpc.v1.security_group_service_pb2.ListSecurityGroupOperationsResponse,
    ]
    """Lists operations for the specified security groups."""

class SecurityGroupServiceAsyncStub:
    """A set of methods for managing SecurityGroup resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.security_group_service_pb2.GetSecurityGroupRequest,
        yandex.cloud.vpc.v1.security_group_pb2.SecurityGroup,
    ]
    """Returns the specified SecurityGroup resource.

    To get the list of all available SecurityGroup resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.security_group_service_pb2.ListSecurityGroupsRequest,
        yandex.cloud.vpc.v1.security_group_service_pb2.ListSecurityGroupsResponse,
    ]
    """Retrieves the list of SecurityGroup resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.security_group_service_pb2.CreateSecurityGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a security group in the specified folder and network."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.security_group_service_pb2.UpdateSecurityGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified security group.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    UpdateRules: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.security_group_service_pb2.UpdateSecurityGroupRulesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the rules of the specified security group."""

    UpdateRule: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.security_group_service_pb2.UpdateSecurityGroupRuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified rule."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.security_group_service_pb2.DeleteSecurityGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified security group."""

    Move: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.security_group_service_pb2.MoveSecurityGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Moves security groups to another folder."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.security_group_service_pb2.ListSecurityGroupOperationsRequest,
        yandex.cloud.vpc.v1.security_group_service_pb2.ListSecurityGroupOperationsResponse,
    ]
    """Lists operations for the specified security groups."""

class SecurityGroupServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing SecurityGroup resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.vpc.v1.security_group_service_pb2.GetSecurityGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.security_group_pb2.SecurityGroup, collections.abc.Awaitable[yandex.cloud.vpc.v1.security_group_pb2.SecurityGroup]]:
        """Returns the specified SecurityGroup resource.

        To get the list of all available SecurityGroup resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.vpc.v1.security_group_service_pb2.ListSecurityGroupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.security_group_service_pb2.ListSecurityGroupsResponse, collections.abc.Awaitable[yandex.cloud.vpc.v1.security_group_service_pb2.ListSecurityGroupsResponse]]:
        """Retrieves the list of SecurityGroup resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.vpc.v1.security_group_service_pb2.CreateSecurityGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a security group in the specified folder and network."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.vpc.v1.security_group_service_pb2.UpdateSecurityGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified security group.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def UpdateRules(
        self,
        request: yandex.cloud.vpc.v1.security_group_service_pb2.UpdateSecurityGroupRulesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the rules of the specified security group."""

    @abc.abstractmethod
    def UpdateRule(
        self,
        request: yandex.cloud.vpc.v1.security_group_service_pb2.UpdateSecurityGroupRuleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified rule."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.vpc.v1.security_group_service_pb2.DeleteSecurityGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified security group."""

    @abc.abstractmethod
    def Move(
        self,
        request: yandex.cloud.vpc.v1.security_group_service_pb2.MoveSecurityGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Moves security groups to another folder."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.vpc.v1.security_group_service_pb2.ListSecurityGroupOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.security_group_service_pb2.ListSecurityGroupOperationsResponse, collections.abc.Awaitable[yandex.cloud.vpc.v1.security_group_service_pb2.ListSecurityGroupOperationsResponse]]:
        """Lists operations for the specified security groups."""

def add_SecurityGroupServiceServicer_to_server(servicer: SecurityGroupServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import yandex.cloud.cdn.v1.origin_pb2
import yandex.cloud.cdn.v1.resource_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetResourceRequest(google.protobuf.message.Message):
    """A request to get a resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of the requested resource."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___GetResourceRequest = GetResourceRequest

@typing.final
class ListResourcesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to request listing for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListResourcesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListResourcesResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListResourcesRequest = ListResourcesRequest

@typing.final
class ListResourcesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """[next_page_token] token allows you to get the next page of results for list requests.
    If the number of results is larger than [ListResourcesRequest.page_size], use
    the [next_page_token] as the value for the [ListResourcesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def resources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cdn.v1.resource_pb2.Resource]:
        """List of the resources"""

    def __init__(
        self,
        *,
        resources: collections.abc.Iterable[yandex.cloud.cdn.v1.resource_pb2.Resource] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "resources", b"resources"]) -> None: ...

global___ListResourcesResponse = ListResourcesResponse

@typing.final
class CreateResourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Origin(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ORIGIN_GROUP_ID_FIELD_NUMBER: builtins.int
        ORIGIN_SOURCE_FIELD_NUMBER: builtins.int
        ORIGIN_SOURCE_PARAMS_FIELD_NUMBER: builtins.int
        origin_group_id: builtins.int
        """ID of pre-created origin group."""
        origin_source: builtins.str
        """Create new Origins group with single source, it's id will be
        returned in result.
        """
        @property
        def origin_source_params(self) -> global___ResourceOriginParams:
            """Set up resource origin parameters."""

        def __init__(
            self,
            *,
            origin_group_id: builtins.int = ...,
            origin_source: builtins.str = ...,
            origin_source_params: global___ResourceOriginParams | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["origin_group_id", b"origin_group_id", "origin_source", b"origin_source", "origin_source_params", b"origin_source_params", "origin_variant", b"origin_variant"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["origin_group_id", b"origin_group_id", "origin_source", b"origin_source", "origin_source_params", b"origin_source_params", "origin_variant", b"origin_variant"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["origin_variant", b"origin_variant"]) -> typing.Literal["origin_group_id", "origin_source", "origin_source_params"] | None: ...

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    CNAME_FIELD_NUMBER: builtins.int
    ORIGIN_FIELD_NUMBER: builtins.int
    SECONDARY_HOSTNAMES_FIELD_NUMBER: builtins.int
    ORIGIN_PROTOCOL_FIELD_NUMBER: builtins.int
    ACTIVE_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    SSL_CERTIFICATE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the to bind with new resource."""
    cname: builtins.str
    """CDN endpoint CNAME, must be unique among clients's resources."""
    origin_protocol: yandex.cloud.cdn.v1.resource_pb2.OriginProtocol.ValueType
    """Specify the protocol schema to be used in communication with origin."""
    @property
    def origin(self) -> global___CreateResourceRequest.Origin:
        """Specify the origins to be used for CDN resources requests."""

    @property
    def secondary_hostnames(self) -> yandex.cloud.cdn.v1.resource_pb2.SecondaryHostnames:
        """List of additional CNAMEs."""

    @property
    def active(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Flag to create Resource either in active or disabled state.
        In active state Origins payload could be transmitted from CDN CNAME requests.
        Default value: true
        """

    @property
    def options(self) -> yandex.cloud.cdn.v1.resource_pb2.ResourceOptions:
        """Resource settings and options to tune CDN edge behavior. Most is unset."""

    @property
    def ssl_certificate(self) -> yandex.cloud.cdn.v1.resource_pb2.SSLTargetCertificate:
        """SSL Certificate options."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels of the resource."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        cname: builtins.str = ...,
        origin: global___CreateResourceRequest.Origin | None = ...,
        secondary_hostnames: yandex.cloud.cdn.v1.resource_pb2.SecondaryHostnames | None = ...,
        origin_protocol: yandex.cloud.cdn.v1.resource_pb2.OriginProtocol.ValueType = ...,
        active: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        options: yandex.cloud.cdn.v1.resource_pb2.ResourceOptions | None = ...,
        ssl_certificate: yandex.cloud.cdn.v1.resource_pb2.SSLTargetCertificate | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["active", b"active", "options", b"options", "origin", b"origin", "secondary_hostnames", b"secondary_hostnames", "ssl_certificate", b"ssl_certificate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["active", b"active", "cname", b"cname", "folder_id", b"folder_id", "labels", b"labels", "options", b"options", "origin", b"origin", "origin_protocol", b"origin_protocol", "secondary_hostnames", b"secondary_hostnames", "ssl_certificate", b"ssl_certificate"]) -> None: ...

global___CreateResourceRequest = CreateResourceRequest

@typing.final
class ResourceOriginParams(google.protobuf.message.Message):
    """A set of resource origin parameters."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_FIELD_NUMBER: builtins.int
    META_FIELD_NUMBER: builtins.int
    source: builtins.str
    """Source of the content."""
    @property
    def meta(self) -> yandex.cloud.cdn.v1.origin_pb2.OriginMeta:
        """Set up type of the origin."""

    def __init__(
        self,
        *,
        source: builtins.str = ...,
        meta: yandex.cloud.cdn.v1.origin_pb2.OriginMeta | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["meta", b"meta"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["meta", b"meta", "source", b"source"]) -> None: ...

global___ResourceOriginParams = ResourceOriginParams

@typing.final
class CreateResourceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of created resource."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___CreateResourceMetadata = CreateResourceMetadata

@typing.final
class UpdateResourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    ORIGIN_GROUP_ID_FIELD_NUMBER: builtins.int
    SECONDARY_HOSTNAMES_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    ORIGIN_PROTOCOL_FIELD_NUMBER: builtins.int
    ACTIVE_FIELD_NUMBER: builtins.int
    SSL_CERTIFICATE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    REMOVE_LABELS_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of updated resource."""
    origin_protocol: yandex.cloud.cdn.v1.resource_pb2.OriginProtocol.ValueType
    """Specify the protocol schema to be used in communication with origin."""
    remove_labels: builtins.bool
    """If flag is set to true resource labels will be deleted."""
    @property
    def origin_group_id(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """ID of updated origin group."""

    @property
    def secondary_hostnames(self) -> yandex.cloud.cdn.v1.resource_pb2.SecondaryHostnames:
        """List of additional CNAMEs."""

    @property
    def options(self) -> yandex.cloud.cdn.v1.resource_pb2.ResourceOptions:
        """Resource settings and options to tune CDN edge behavior."""

    @property
    def active(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Flag to create Resource either in active or disabled state.
        In active state Origins payload could be transmitted from CDN CNAME requests.
        Default value: true
        """

    @property
    def ssl_certificate(self) -> yandex.cloud.cdn.v1.resource_pb2.SSLTargetCertificate:
        """SSL Certificate options."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels. At some point will be needed for granular detailing."""

    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
        origin_group_id: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        secondary_hostnames: yandex.cloud.cdn.v1.resource_pb2.SecondaryHostnames | None = ...,
        options: yandex.cloud.cdn.v1.resource_pb2.ResourceOptions | None = ...,
        origin_protocol: yandex.cloud.cdn.v1.resource_pb2.OriginProtocol.ValueType = ...,
        active: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        ssl_certificate: yandex.cloud.cdn.v1.resource_pb2.SSLTargetCertificate | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        remove_labels: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["active", b"active", "options", b"options", "origin_group_id", b"origin_group_id", "secondary_hostnames", b"secondary_hostnames", "ssl_certificate", b"ssl_certificate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["active", b"active", "labels", b"labels", "options", b"options", "origin_group_id", b"origin_group_id", "origin_protocol", b"origin_protocol", "remove_labels", b"remove_labels", "resource_id", b"resource_id", "secondary_hostnames", b"secondary_hostnames", "ssl_certificate", b"ssl_certificate"]) -> None: ...

global___UpdateResourceRequest = UpdateResourceRequest

@typing.final
class UpdateResourceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of updated resource."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___UpdateResourceMetadata = UpdateResourceMetadata

@typing.final
class DeleteResourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of resource to delete."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___DeleteResourceRequest = DeleteResourceRequest

@typing.final
class DeleteResourceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of deleted resource."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___DeleteResourceMetadata = DeleteResourceMetadata

@typing.final
class GetProviderCNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID to get provider's CNAME."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id"]) -> None: ...

global___GetProviderCNameRequest = GetProviderCNameRequest

@typing.final
class GetProviderCNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CNAME_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    cname: builtins.str
    """Provider's CNAME."""
    folder_id: builtins.str
    """ID of the folder that the provider belongs to."""
    def __init__(
        self,
        *,
        cname: builtins.str = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cname", b"cname", "folder_id", b"folder_id"]) -> None: ...

global___GetProviderCNameResponse = GetProviderCNameResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class BackupRetentionPolicyServiceStub:
    """A set of methods for managing PostgreSQL Cluster backup retention policies."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.ListBackupRetentionPoliciesRequest,
        yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.ListBackupRetentionPoliciesResponse,
    ]
    """List all retention policies."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.CreateBackupRetentionPolicyRequest,
        yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.CreateBackupRetentionPolicyResponse,
    ]
    """Add a new retention policy."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.DeleteBackupRetentionPolicyRequest,
        yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.DeleteBackupRetentionPolicyResponse,
    ]
    """Delete retention policy."""

class BackupRetentionPolicyServiceAsyncStub:
    """A set of methods for managing PostgreSQL Cluster backup retention policies."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.ListBackupRetentionPoliciesRequest,
        yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.ListBackupRetentionPoliciesResponse,
    ]
    """List all retention policies."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.CreateBackupRetentionPolicyRequest,
        yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.CreateBackupRetentionPolicyResponse,
    ]
    """Add a new retention policy."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.DeleteBackupRetentionPolicyRequest,
        yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.DeleteBackupRetentionPolicyResponse,
    ]
    """Delete retention policy."""

class BackupRetentionPolicyServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing PostgreSQL Cluster backup retention policies."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.ListBackupRetentionPoliciesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.ListBackupRetentionPoliciesResponse, collections.abc.Awaitable[yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.ListBackupRetentionPoliciesResponse]]:
        """List all retention policies."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.CreateBackupRetentionPolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.CreateBackupRetentionPolicyResponse, collections.abc.Awaitable[yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.CreateBackupRetentionPolicyResponse]]:
        """Add a new retention policy."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.DeleteBackupRetentionPolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.DeleteBackupRetentionPolicyResponse, collections.abc.Awaitable[yandex.cloud.mdb.postgresql.v1.backup_retention_policy_service_pb2.DeleteBackupRetentionPolicyResponse]]:
        """Delete retention policy."""

def add_BackupRetentionPolicyServiceServicer_to_server(servicer: BackupRetentionPolicyServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
